@@ -1,11 +1,11 @@
 #pragma once
-#define GIT_COMMIT_HASH    "ab1d80f3d6aebd57a0971b53a1993b1c1dfe0b09"
-#define GIT_BRANCH         "v0.53.1"
-#define GIT_COMMIT_MESSAGE "version: bump to 0.53.1"
-#define GIT_COMMIT_DATE    "Fri Jan 2 21:20:57 2026"
+#define GIT_COMMIT_HASH    "39f3feddbee4a66be9608ed1eb7e73878d596b50"
+#define GIT_BRANCH         "v0.53.2"
+#define GIT_COMMIT_MESSAGE "[gha] Nix: update inputs"
+#define GIT_COMMIT_DATE    "Fri Jan 23 13:15:35 2026"
 #define GIT_DIRTY          "clean"
-#define GIT_TAG            "v0.53.1"
-#define GIT_COMMITS        "6766"
+#define GIT_TAG            "v0.53.2"
+#define GIT_COMMITS        "6790"
 
 #define AQUAMARINE_VERSION "0.10.0"
 // clang-format off
@@ -13,7 +13,7 @@
 #define AQUAMARINE_VERSION_MINOR 10
 #define AQUAMARINE_VERSION_PATCH 0
 // clang-format on
-#define HYPRLANG_VERSION     "0.6.7"
+#define HYPRLANG_VERSION     "0.6.8"
 #define HYPRUTILS_VERSION    "0.11.0"
 #define HYPRCURSOR_VERSION   "0.1.13"
 #define HYPRGRAPHICS_VERSION "0.5.0"
